@@ -25,9 +25,7 @@
 ##'
 ##' @importFrom nlme lme
 ##'
-##' @importFrom gdata rename.vars
-##'
-##' @author Thiago de Paula Oliveira, \email{thiago.paula.oliveira@@usp.br}
+##' @author Thiago de Paula Oliveira, \email{thiago.paula.oliveira@@alumni.usp.br}
 ##'
 ##' @keywords internal
 init<-function(var.class, weights.form, REML, qf, qr, pdmat, dataset,
@@ -147,3 +145,62 @@ init<-function(var.class, weights.form, REML, qf, qr, pdmat, dataset,
                                       call.=FALSE)
   return((list2env(initList, .GlobalEnv)))
 }
+
+#-----------------------------------------------------------------------
+# Rename vars
+#-----------------------------------------------------------------------
+##' @title Internal Function to Prepare \code{\link[lcc]{lccModel}}
+##'   Function
+##'
+##' @description This is an internally called function used to verify
+##'   the specification of variance-covariance matrices and likelihood
+##'   based method.
+##'
+##' @usage NULL
+##'
+##' @author Code by Don MacQueen \email{macq\@llnl.gov}
+##'
+##' @keywords internal
+
+rename.vars <- function(data,from='',to='',info=TRUE) {
+
+   dsn <- deparse(substitute(data))
+   dfn <- names(data)
+
+   if ( length(from) != length(to)) {
+     cat('--------- from and to not same length ---------\n')
+     stop()
+   }
+
+   if (length(dfn) < length(to)) {
+     cat('--------- too many new names ---------\n')
+     stop()
+   }
+
+   chng <- match(from,dfn)
+
+   frm.in <- from %in% dfn
+   if (!all(frm.in) ) {
+     cat('---------- some of the from names not found in',dsn,'\n')
+     stop()
+   }
+
+   if (length(to) != length(unique(to))) {
+     cat('---------- New names not unique\n')
+     stop()
+   }
+
+   dfn.new <- dfn
+   dfn.new[chng] <- to
+   if (info) cat('\nChanging in',dsn)
+   tmp <- rbind(from,to)
+   dimnames(tmp)[[1]] <- c('From:','To:')
+   dimnames(tmp)[[2]] <- rep('',length(from))
+   if (info)
+     {
+       print(tmp,quote=FALSE)
+       cat("\n")
+     }
+   names(data) <- dfn.new
+   data
+}
